selectortools.select_all_but_last_logical_tie_in_pitched_runs
=============================================================

.. autofunction:: abjad.tools.selectortools.select_all_but_last_logical_tie_in_pitched_runs.select_all_but_last_logical_tie_in_pitched_runs
